Method: Minfraud.host
- Defined in:
- lib/minfraud.rb
.host ⇒ String?
The host to use when connecting to the web service. By default, the client connects to the production host. However, during testing and development, you can set this option to ‘sandbox.maxmind.com’ to use the Sandbox environment’s host. The sandbox allows you to experiment with the API without affecting your production data.
56 57 58 |
# File 'lib/minfraud.rb', line 56 def host @host end |