Method: Minfraud::Components::Report::Transaction#ip_address

Defined in:
lib/minfraud/components/report/transaction.rb

#ip_addressString?

The IP address of the customer placing the order. This should be passed as a string like “152.216.7.110”. This field is not required if you provide at least one of the transaction’s minfraud_id, maxmind_id, or transaction_id. You are encouraged to provide it, if possible.

Returns:

  • (String, nil)


20
21
22
# File 'lib/minfraud/components/report/transaction.rb', line 20

def ip_address
  @ip_address
end