Method: Minfraud::Components::Report::Transaction#notes

Defined in:
lib/minfraud/components/report/transaction.rb

#notesString?

Your notes on the fraud tag associated with the transaction. We manually review many reported transactions to improve our scoring for you so any additional details to help us understand context are helpful.

Returns:

  • (String, nil)


64
65
66
# File 'lib/minfraud/components/report/transaction.rb', line 64

def notes
  @notes
end