Module: Minfraud::Enum
- Included in:
- Components::Event, Components::Payment, Components::Report::Transaction, Components::Shipping
- Defined in:
- lib/minfraud/enum.rb
Overview
Enum provides helpers for working with attributes with enumerated types.
Defined Under Namespace
Modules: ClassMethods
Class Method Summary collapse
-
.included(base) ⇒ Class
Hook method called when the module is included into a class.
Class Method Details
.included(base) ⇒ Class
Hook method called when the module is included into a class. Extends the class with ClassMethods.
12 13 14 |
# File 'lib/minfraud/enum.rb', line 12 def self.included(base) base.extend(ClassMethods) end |