Class: Minfraud::Model::Email
- Inherits:
-
Abstract
- Object
- Abstract
- Minfraud::Model::Email
- Defined in:
- lib/minfraud/model/email.rb
Overview
Model containing information about the email address.
Instance Attribute Summary collapse
-
#domain ⇒ Minfraud::Model::EmailDomain
readonly
An object containing information about the email domain.
-
#first_seen ⇒ String?
readonly
A date string (e.g. 2017-04-24) to identify the date an email address was first seen by MaxMind.
-
#is_disposable ⇒ Boolean?
readonly
Whether this email address is from a disposable email provider.
-
#is_free ⇒ Boolean?
readonly
This property is true if MaxMind believes that this email is hosted by a free email provider such as Gmail or Yahoo! Mail.
-
#is_high_risk ⇒ Boolean?
readonly
This field is true if MaxMind believes that this email is likely to be used for fraud.
Instance Attribute Details
#domain ⇒ Minfraud::Model::EmailDomain (readonly)
An object containing information about the email domain.
13 14 15 |
# File 'lib/minfraud/model/email.rb', line 13 def domain @domain end |
#first_seen ⇒ String? (readonly)
A date string (e.g. 2017-04-24) to identify the date an email address was first seen by MaxMind. This is expressed using the ISO 8601 date format YYYY-MM-DD. The earliest date that may be returned is January 1, 2008.
21 22 23 |
# File 'lib/minfraud/model/email.rb', line 21 def first_seen @first_seen end |
#is_disposable ⇒ Boolean? (readonly)
Whether this email address is from a disposable email provider. The value will be nil when no email address or email domain has been passed as an input.
28 29 30 |
# File 'lib/minfraud/model/email.rb', line 28 def is_disposable @is_disposable end |
#is_free ⇒ Boolean? (readonly)
This property is true if MaxMind believes that this email is hosted by a free email provider such as Gmail or Yahoo! Mail.
34 35 36 |
# File 'lib/minfraud/model/email.rb', line 34 def is_free @is_free end |
#is_high_risk ⇒ Boolean? (readonly)
This field is true if MaxMind believes that this email is likely to be used for fraud. Note that this is also factored into the overall risk_score in the response as well.
41 42 43 |
# File 'lib/minfraud/model/email.rb', line 41 def is_high_risk @is_high_risk end |