Class: Minfraud::Model::EmailDomain
- Inherits:
-
Abstract
- Object
- Abstract
- Minfraud::Model::EmailDomain
- Defined in:
- lib/minfraud/model/email_domain.rb
Overview
Model containing information about the email domain.
Instance Attribute Summary collapse
-
#classification ⇒ String?
readonly
A classification of the domain.
-
#first_seen ⇒ String?
readonly
A date string (e.g. 2019-01-01) to identify the date an email domain was first seen by MaxMind.
-
#risk ⇒ Float?
readonly
A risk score ranging from 0.01 to 99.
-
#visit ⇒ Minfraud::Model::EmailDomainVisit?
readonly
An object containing information about an automated visit to the email domain.
-
#volume ⇒ Float?
readonly
Activity across the minFraud network expressed as sightings per million.
Instance Attribute Details
#classification ⇒ String? (readonly)
A classification of the domain. Possible values are:
- business
- education
- government
- isp_email
17 18 19 |
# File 'lib/minfraud/model/email_domain.rb', line 17 def classification @classification end |
#first_seen ⇒ String? (readonly)
A date string (e.g. 2019-01-01) to identify the date an email domain was first seen by MaxMind. This is expressed using the ISO 8601 date format YYYY-MM-DD. The earliest date that may be returned is January 1, 2019.
25 26 27 |
# File 'lib/minfraud/model/email_domain.rb', line 25 def first_seen @first_seen end |
#risk ⇒ Float? (readonly)
A risk score ranging from 0.01 to 99. Higher values indicate greater risk.
31 32 33 |
# File 'lib/minfraud/model/email_domain.rb', line 31 def risk @risk end |
#visit ⇒ Minfraud::Model::EmailDomainVisit? (readonly)
An object containing information about an automated visit to the email domain.
37 38 39 |
# File 'lib/minfraud/model/email_domain.rb', line 37 def visit @visit end |
#volume ⇒ Float? (readonly)
Activity across the minFraud network expressed as sightings per million. The value ranges from 0.001 to 1,000,000.
43 44 45 |
# File 'lib/minfraud/model/email_domain.rb', line 43 def volume @volume end |