Class: Minfraud::Model::EmailDomainVisit

Inherits:
Abstract
  • Object
show all
Defined in:
lib/minfraud/model/email_domain_visit.rb

Overview

Model containing information about an automated visit to the email domain.

Instance Attribute Summary collapse

Instance Attribute Details

#has_redirectBoolean? (readonly)

This is true if the domain in the request has redirects (configured to automatically send visitors to another URL). Otherwise, this will be nil.

Returns:

  • (Boolean, nil)


15
16
17
# File 'lib/minfraud/model/email_domain_visit.rb', line 15

def has_redirect
  @has_redirect
end

#last_visited_onString? (readonly)

A date string (e.g. 2025-11-15) identifying the date the automated visit was completed. This is expressed using the ISO 8601 date format.

Returns:

  • (String, nil)


21
22
23
# File 'lib/minfraud/model/email_domain_visit.rb', line 21

def last_visited_on
  @last_visited_on
end

#statusString? (readonly)

The status of the domain. Possible values are:

  • live - The domain is reachable and serving content normally.
  • dns_error - The domain is missing, expired, or DNS is misconfigured.
  • network_error - The domain is offline, blocked, or unreachable.
  • http_error - The domain is reachable but the web application had a problem or denied the request.
  • parked - The domain is live and is in a parked state.
  • pre_development - The domain is live and is in a pre-development state.

Returns:

  • (String, nil)


34
35
36
# File 'lib/minfraud/model/email_domain_visit.rb', line 34

def status
  @status
end